(* HCoop Domtool (http://hcoop.sourceforge.net/)
 * Copyright (c) 2006, Adam Chlipala
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *)

(* Network message data structures *)

structure MsgTypes = struct

datatype msg =
	 MsgOk
       (* Your request was processed successfully. *)
       | MsgError of string
       (* Your request went wrong in some way. *)
       | MsgConfig of string
       (* Configuration source code *)
       | MsgFile of Slave.file_status
       (* The status of a configuration file has changed. *)
       | MsgDoFiles
       (* Perform the actions associated with the MsgFiles sent previously. *)
       | MsgGrant of Acl.acl
       (* Grant a permission *)
       | MsgRevoke of Acl.acl
       (* Revoke a permission *)
       | MsgListPerms of string
       (* List all of a user's permissions *)
       | MsgPerms of (string * string list) list
       (* A response to MsgListPerms, giving a permission class and all values
	* for which the user is authorized in that class *)
       | MsgWhoHas of {class : string, value : string}
       (* Which users have this permission? *)
       | MsgWhoHasResponse of string list
       (* These are the users! *)
       | MsgMultiConfig of string list
       (* Multiple Domtool sources in dependency order *)
       | MsgRmdom of string list
       (* Remove all configuration associated with some domains and revoke
	* rights to those domains from all users. *)
       | MsgRegenerate
       (* Make a clean slate of it and reprocess all configuration from scratch. *)
       | MsgRmuser of string
       (* Remove all ACL entries for a user, and remove all domains to which
	* that user and no one else has rights. *)
       | MsgCreateDbUser of {dbtype : string, passwd : string option}
       (* Request creation of a user for the named DBMS type *)
       | MsgCreateDbTable of {dbtype : string, dbname : string}
       (* Request creation of a DBMS table *)
       | MsgNewMailbox of {domain : string, user : string,
			   passwd : string, mailbox : string}
       (* Request creation of a new vmail mapping *)
       | MsgPasswdMailbox of {domain : string, user : string, passwd : string}
       (* Change a vmail account's password *)
       | MsgRmMailbox of {domain : string, user : string}
       (* Remove a vmail mapping *)
       | MsgListMailboxes of string
       (* List all mailboxes for a domain *)
       | MsgMailboxes of {user : string, mailbox : string} list
       (* Reply to MsgListMailboxes *)
       | MsgSaQuery of string
       (* Check on the SpamAsssassin filtering status of a user or e-mail address *)
       | MsgSaStatus of bool
       (* Response to MsgSaQuery *)
       | MsgSaSet of string * bool
       (* Set the filtering status of a user or e-mail address *)

end
